@@ -1,7 +1,8 @@
 import re
 import uuid
-from typing import Any, Callable, Dict, List, NamedTuple, Pattern, Tuple, Union
+from typing import Any, Callable, Dict, NamedTuple, Pattern, Tuple, Union
 
+from .errors import RouteError
 from .hook import Hook
 
 
@@ -26,10 +27,6 @@ PARAM_REGEX = re.compile(r"{([a-zA-Z_]\w*)(:[a-zA-Z_]\w*)?}")
 Params = Dict[str, Any]
 
 
-class RouteError(Exception):
-    pass
-
-
 class Route:
     """
     :raises: RouteError
@@ -37,18 +34,16 @@ class Route:
 
     def __init__(
         self,
-        path: str,
+        name: str,
         fn: Callable,
+        path: Union[str, None] = None,
         opts: Union[Dict[str, Any], None] = None,
-        after: Union[None, str, List[str]] = None,
     ):
-        self.path = path
-        self.path_regex, self.convertors = compile_path(path)
+        self.name = name
+        self.path = path if path is not None else name
+        self.path_regex, self.convertors = compile_path(self.path)
         self.opts: Dict[str, Any] = opts or {}
         self.hook = Hook(fn)
-        if isinstance(after, str):
-            after = [after]
-        self.after: List[str] = after or []
 
     def match(self, name: str) -> Union[Params, None]:
         match = self.path_regex.match(name)
